% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/importData.R
\name{importHaplo}
\alias{importHaplo}
\title{Import haplotypes}
\usage{
importHaplo(haplo, genMap, ploidy = 2L, ped = NULL)
}
\arguments{
\item{haplo}{a matrix of haplotypes}

\item{genMap}{genetic map as a data.frame. The first
three columns must be: marker name, chromosome, and 
map position (Morgans). Marker name and chromosome are 
coerced using as.character. See \code{\link{importGenMap}}}

\item{ploidy}{ploidy level of the organism}

\item{ped}{an optional pedigree for the supplied 
genotypes. See details.}
}
\value{
a \code{\link{MapPop-class}} if ped is NULL,
otherwise a \code{\link{NamedMapPop-class}}
}
\description{
Formats haplotype in a matrix format to an 
AlphaSimR population that can be used to 
initialize a simulation. This function serves 
as wrapper for \code{\link{newMapPop}} that 
utilizes a more user friendly input format.
}
\details{
The optional pedigree can be a data.frame, matrix or a vector. 
If the object is a data.frame or matrix, the first three 
columns must include information in the following order: id, 
mother, and father. All values are coerced using 
as.character. If the object is a vector, it is assumed to only 
include the id. In this case, the mother and father will be set 
to "0" for all individuals.
}
\examples{
haplo = rbind(c(1,1,0,1,0),
              c(1,1,0,1,0),
              c(0,1,1,0,0),
              c(0,1,1,0,0))
colnames(haplo) = letters[1:5]

genMap = data.frame(markerName=letters[1:5],
                    chromosome=c(1,1,1,2,2),
                    position=c(0,0.5,1,0.15,0.4))

ped = data.frame(id=c("a","b"),
                 mother=c(0,0),
                 father=c(0,0))

founderPop = importHaplo(haplo=haplo, 
                         genMap=genMap,
                         ploidy=2L,
                         ped=ped)

}
