% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selection.R
\name{selectFam}
\alias{selectFam}
\title{Select families}
\usage{
selectFam(
  pop,
  nFam,
  trait = 1,
  use = "pheno",
  sex = "B",
  famType = "B",
  selectTop = TRUE,
  returnPop = TRUE,
  candidates = NULL,
  simParam = NULL,
  ...
)
}
\arguments{
\item{pop}{and object of \code{\link{Pop-class}},
\code{\link{HybridPop-class}} or \code{\link{MultiPop-class}}}

\item{nFam}{the number of families to select}

\item{trait}{the trait for selection. Either a number indicating
a single trait or a function returning a vector of length nInd.
The function must work on a vector or matrix of \code{use} values as
\code{trait(pop@use, ...)} - depending on what \code{use} is.
See the examples and \code{\link{selIndex}}.}

\item{use}{the selection criterion. Either a character
(genetic values "gv", estimated breeding values "ebv", breeding values "bv",
phenotypes "pheno", or randomly "rand") or
a function returning a vector of length nInd.
The function must work on \code{pop} as \code{use(pop, trait, ...)} or
as \code{trait(pop@use, ...)} depending on what \code{trait} is.
See the examples.}

\item{sex}{which sex to select. Use "B" for both, "F" for
females and "M" for males. If the simulation is not using sexes,
the argument is ignored.}

\item{famType}{which type of family to select. Use "B" for
full-sib families, "F" for half-sib families on female side and "M"
for half-sib families on the male side.}

\item{selectTop}{selects highest values if true.
Selects lowest values if false.}

\item{returnPop}{should results be returned as a
\code{\link{Pop-class}}. If FALSE, only the index of selected
individuals is returned.}

\item{candidates}{an optional vector of eligible selection candidates.}

\item{simParam}{an object of \code{\link{SimParam}}}

\item{...}{additional arguments if using a function for
\code{trait} and \code{use}}
}
\value{
Returns an object of \code{\link{Pop-class}},
\code{\link{HybridPop-class}} or \code{\link{MultiPop-class}}
}
\description{
Selects a subset of full-sib families from a
population.
}
\examples{
#Create founder haplotypes
founderPop = quickHaplo(nInd=10, nChr=1, segSites=10)

#Set simulation parameters
SP = SimParam$new(founderPop)
\dontshow{SP$nThreads = 1L}
SP$addTraitA(10)
SP$setVarE(h2=0.5)

#Create population
pop = newPop(founderPop, simParam=SP)

#Create 3 biparental families with 10 progeny
pop2 = randCross(pop, nCrosses=3, nProgeny=10, simParam=SP)

#Select best 2 families
pop3 = selectFam(pop2, 2, simParam=SP)

}
